@@ -1,24 +1,22 @@
+import django
 
-VERSION = (0, 5, 3)
+
+__version__ = "0.13.1"
+VERSION = tuple(__version__.split("."))
+
+if django.VERSION < (3, 2):  # pragma: no cover
+    default_app_config = "mptt.apps.MpttConfig"
 
 
-# NOTE: This method was removed in 0.4.0, but restored in 0.4.2 after use-cases were
-# reported that were impossible by merely subclassing MPTTModel.
 def register(*args, **kwargs):
     """
     Registers a model class as an MPTTModel, adding MPTT fields and adding MPTTModel to __bases__.
     This is equivalent to just subclassing MPTTModel, but works for an already-created model.
     """
     from mptt.models import MPTTModelBase
+
     return MPTTModelBase.register(*args, **kwargs)
 
 
-# Also removed in 0.4.0 but restored in 0.4.2, otherwise this 0.3-compatibility code will break:
-#     if hasattr(mptt, 'register'):
-#         try:
-#             mptt.register(...)
-#         except mptt.AlreadyRegistered:
-#             pass
-
 class AlreadyRegistered(Exception):
     "Deprecated - don't use this anymore. It's never thrown, you don't need to catch it"
